summaryrefslogtreecommitdiffstats
path: root/khtml/dom/html_inline.h
diff options
context:
space:
mode:
Diffstat (limited to 'khtml/dom/html_inline.h')
-rw-r--r--khtml/dom/html_inline.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/khtml/dom/html_inline.h b/khtml/dom/html_inline.h
index 6c1b2d2a2..9db17efb4 100644
--- a/khtml/dom/html_inline.h
+++ b/khtml/dom/html_inline.h
@@ -89,7 +89,7 @@ public:
/**
* Comma-separated list of lengths, defining an active region
* geometry. See also \c shape for the shape of the
* region. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-coords">
* coords attribute definition </a> in HTML 4.0.
@@ -168,16 +168,16 @@ public:
void setRev( const DOMString & );
/**
* The shape of the active area. The coordinates are given by
* \c coords . See the <a
* href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-shape">
* shape attribute definition </a> in HTML 4.0.
*
*/
- DOMString shape() const;
+ DOMString tqshape() const;
/**
- * see shape
+ * see tqshape
*/
void setShape( const DOMString & );
@@ -89,7 +89,7 @@ public:
/**
* Comma-separated list of lengths, defining an active region
- * geometry. See also \c shape for the shape of the
+ * tqgeometry. See also \c tqshape for the tqshape of the
* region. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-coords">
@@ -168,16 +168,16 @@ public:
void setRev( const DOMString & );
/**
- * The shape of the active area. The coordinates are given by
+ * The tqshape of the active area. The coordinates are given by
* \c coords . See the <a
@@ -168,16 +168,16 @@ public:
* \c coords . See the <a
- * href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-shape">
- * shape attribute definition </a> in HTML 4.0.
+ * href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-tqshape">
+ * tqshape attribute definition </a> in HTML 4.0.
*
*/